@@ -2,4 +2,7 @@ from .awaiting import AwaitingHttp
 from .blocking import BlockingHttp
 
 
-assert AwaitingHttp, BlockingHttp
+__all__ = [
+    "AwaitingHttp",
+    "BlockingHttp"
+]
