@@ -1,9 +1,15 @@
-from ..base import BackupBase
+from typing import TYPE_CHECKING
 
+from ..base import BackupBase
 from ...routes import SERVER
 
+if TYPE_CHECKING:
+    from ... import Blocking
+
 
 class BlockingBackup(BackupBase):
+    _context: "Blocking"
+
     def restore(self) -> None:
         """Used to restore a backup.
         """
