@@ -1,8 +1,5 @@
 import os
 
-
-EMAIL = ""
-PASSWORD = ""
 TEST_IMAGE_DIRETORY = os.path.join(
     os.path.dirname(os.path.realpath(__file__)),
     "test.jpg"
