@@ -14,18 +14,22 @@ from ..models.metrics import (
     PlayerModel,
     PlayersOnlineGraphModel
 )
-from ..models.match import MatchModel, TeamModel, MatchPlayerModel
+from ..models.match import (
+    MatchModel, TeamModel, MatchPlayerModel, MatchSeriesModel
+)
 
 from ..server.awaiting.backup import AwaitingBackup
 from ..server.awaiting.file import AwaitingFile
 
-from ..match.awaiting import AwaitingMatch
+from ..match.awaiting import AwaitingMatch, AwaitingSeries
 
 from ..server.awaiting import ServerAwaiting
 
 from .. import Awaiting
 
-from ..settings import ServerSettings, MatchSettings
+from ..settings import (
+    MatchMapSettings, ServerSettings, MatchSettings, MatchSeriesSettings
+)
 
 
 class TestAwaitingClient(asynctest.TestCase):
@@ -181,6 +185,42 @@ class TestAwaitingClient(asynctest.TestCase):
         for player in match_data.players():
             self.assertIsInstance(player, MatchPlayerModel)
 
+        series_data, series = await server.create_series(
+            MatchSeriesSettings(
+                MatchSettings(
+                ).team_1(
+                    [
+                        "[U:1:116962485]",
+                        76561198017567105,
+                        "STEAM_0:1:186064092"
+                    ]
+                ).team_2(
+                    [
+                        "[U:1:320762620]",
+                        "STEAM_1:1:83437164",
+                        76561198214871324
+                    ]
+                ),
+                message_prefix="Greg",
+            ).maps([
+                MatchMapSettings(),
+                MatchMapSettings(),
+                MatchMapSettings()
+            ])
+        )
+
+        self.assertIsInstance(series_data, MatchSeriesModel)
+        self.assertIsInstance(series, AwaitingSeries)
+
+        for match in series_data.matches():
+            self.assertIsInstance(match.team_1, TeamModel)
+            self.assertIsInstance(match.team_2, TeamModel)
+
+            for player in match.players():
+                self.assertIsInstance(player, MatchPlayerModel)
+
+        self.assertIsInstance(await series.get(), MatchSeriesModel)
+
         self.assertIsNone(await server.delete())
 
     async def test_awaiting_server_valheim(self):
